@@ -911,6 +911,8 @@ sub logcluck {
 
   if ($self->is_warn()) {
     my $message = Carp::longmess($msg);
+    local $Log::Log4perl::caller_depth = 
+          $Log::Log4perl::caller_depth + 1;
     foreach (split(/\n/, $message)) {
       $self->warn("$_\n");
     }
@@ -928,6 +930,8 @@ sub logcarp {
 
   if ($self->is_warn()) {
     my $message = Carp::shortmess($msg);
+    local $Log::Log4perl::caller_depth = 
+          $Log::Log4perl::caller_depth + 1;
     foreach (split(/\n/, $message)) {
       $self->warn("$_\n");
     }
@@ -946,6 +950,8 @@ sub logcroak {
   my $msg = $self->warning_render(@_);
 
   my $message = Carp::shortmess($msg);
+  local $Log::Log4perl::caller_depth = 
+        $Log::Log4perl::caller_depth + 1;
   if ($self->is_fatal()) {
     foreach (split(/\n/, $message)) {
       $self->fatal("$_\n");
@@ -963,9 +969,11 @@ sub logconfess {
   my $self = shift;
 
   my $msg = $self->warning_render(@_);
-  local $Carp::CarpLevel = 2;
+  local $Carp::CarpLevel = $Carp::CarpLevel + 1;
 
   my $message = Carp::longmess($msg);
+  local $Log::Log4perl::caller_depth = 
+        $Log::Log4perl::caller_depth + 1;
   if ($self->is_fatal()) {
     foreach (split(/\n/, $message)) {
       $self->fatal("$_\n");
